@@ -57,7 +57,7 @@ sub set_header {
 
 		'=head2 SYNOPSIS
 
-PACKAGE NAME: 
+PERL PROGRAM NAME: 
 
 AUTHOR:  
 
