@@ -2,6 +2,19 @@ package App::SeismicUnixGui::misc::oop_pod_header;
 use Moose;
 our $VERSION = '0.0.1';
 
+
+use aliased 'App::SeismicUnixGui::misc::L_SU_global_constants';
+
+=head2 instantiation of packages
+
+=cut
+
+my $get           = L_SU_global_constants->new();
+
+my $var          = $get->var();
+
+my $program_title = $var->{_program_title};
+
 =head2 Default perl lines for the pod_headers of the file
 
  _first_entry_num is normally 1
@@ -9,21 +22,28 @@ our $VERSION = '0.0.1';
 
 =cut
 
+my $time_stamp = localtime;
+
 my @head;
 
 $head[0] =
 
 '=head2 SYNOPSIS
 
-PACKAGE NAME: 
+PERL PROGRAM NAME: 
 
-AUTHOR:  
+AUTHOR:
 
-DATE:
+'.
+"DATE: $time_stamp \n\n".
 
-DESCRIPTION:
+'DESCRIPTION:
 
-Version:
+'.
+
+"Built using Version: $program_title \n\n".
+
+'
 
 =head2 USE
 
