@@ -5,7 +5,7 @@ package App::SeismicUnixGui::misc::su_param;
 
 =head2 SYNOPSIS 
 
- PERL PACKAGE NAME: su_param 
+ PERL PERL PROGRAM NAME: su_param 
  AUTHOR: 	Juan Lorenzo
  DATE: 		May 5 2018 
 
@@ -476,21 +476,8 @@ sub _check4local_config {
 		  $L_SU_path->get_pathNmodule_spec_w_slash_pm();
 		my $pathNmodule_spec_w_colon =
 		  $L_SU_path->get_pathNmodule_spec_w_colon();
-														 #
-		  #		my $L_SU_global_constants = L_SU_global_constants->new();
-		  #
-		  #		my $module_spec_pm        = $program_name . '_spec.pm';
-		  #
-		  #		$L_SU_global_constants->set_file_name($module_spec_pm);
-		  #		my $slash_path4spec = $L_SU_global_constants->get_path4spec_file();
-		  #		my $slash_pathNmodule_spec_pm =
-		  #		  $slash_path4spec . '/' . $module_spec_pm;
-		  #
-		  #		$L_SU_global_constants->set_program_name($program_name);
-		  #		my $colon_pathNmodule_spec =
-		  #		  $L_SU_global_constants->get_colon_pathNmodule_spec();
-		  #
-		 #	 	print("1. _get_suffix_aref, prog_name: $slash_pathNmodule_spec_pm\n");
+		  
+		 # 	print("1. su_param,_get_suffix_aref, prog_name: $pathNmodule_spec_w_slash_pm\n");
 		 #	 	print("1. _get_suffix_aref, prog_name: $colon_pathNmodule_spec\n");
 
 		if ( length $pathNmodule_spec_w_slash_pm ) {
