@@ -4,8 +4,8 @@ package App::SeismicUnixGui::sunix::model::sufdmod1;
 
 =head2 SYNOPSIS
 
- PACKAGE NAME:  SUFDMOD1 - Finite difference modelling (1-D first order) for the	
- AUTHOR: Juan Lorenzo
+ PERL PROGRAM NAME:  SUFDMOD1 - Finite difference modelling (1-D first order) for the	
+AUTHOR: Juan Lorenzo (Perl module only)
  DATE:   
  DESCRIPTION:
  Version: 
