@@ -4,8 +4,8 @@ package App::SeismicUnixGui::sunix::model::sufdmod2;
 
 =head2 SYNOPSIS
 
- PACKAGE NAME:  SUFDMOD2 - Finite-Difference MODeling (2nd order) for acoustic wave equation
- AUTHOR: Juan Lorenzo
+ PERL PROGRAM NAME:  SUFDMOD2 - Finite-Difference MODeling (2nd order) for acoustic wave equation
+AUTHOR: Juan Lorenzo (Perl module only)
  DATE:   
  DESCRIPTION:
  Version: 
