@@ -2,8 +2,8 @@ package App::SeismicUnixGui::sunix::plot::lcmap;
 
 =head2 SYNOPSIS
 
-PACKAGE NAME:
-AUTHOR:  
+PERL PROGRAM NAME:
+AUTHOR: Juan Lorenzo (Perl module only)
 
 DATE:
 
