@@ -4,8 +4,8 @@ package App::SeismicUnixGui::sunix::plot::suxwigb;
 
 =head2 SYNOPSIS
 
- PACKAGE NAME:  SUXWIGB - X-windows Bit-mapped WIGgle plot of a segy data set		
- AUTHOR: Juan Lorenzo
+ PERL PROGRAM NAME:  SUXWIGB - X-windows Bit-mapped WIGgle plot of a segy data set		
+AUTHOR: Juan Lorenzo (Perl module only)
  DATE:   
  DESCRIPTION:
  Version: 
@@ -196,7 +196,7 @@ XWIGB - X WIGgle-trace plot of f(x1,x2) via Bitmap
  in each file as npair=npair1,npair2,... .                             
 
 
- AUTHOR:  Dave Hale, Colorado School of Mines, 08/09/90
+ Author:  Dave Hale, Colorado School of Mines, 08/09/90
 
  Endian stuff by: 
     Morten Wendell Pedersen, Aarhus University (visiting CSM, June 1995)
